meta_package_manager.managers.mas — Meta Package Manager 2.4.1 documentation

# `meta_package_manager.managers.mas`

class `meta_package_manager.managers.mas.` `MAS`

  Bases: `meta_package_manager.base.PackageManager`

  `cli_path` = u'/usr/local/bin/mas'
  `platforms` = frozenset([u'macos'])
  `requirement` = u'>= 1.3.1'
  `name` = u'Mac AppStore'
  `get_version`()

    Fetch version from `mas version` output.

  `installed`

    Fetch installed packages from `mas list` output.

    Raw CLI output samples:

        $ mas list
        408981434 iMovie (10.1.4)
        747648890 Telegram (2.30)

  `outdated`

    Fetch outdated packages from `mas outdated` output.

    Raw CLI output samples:

        $ mas outdated

  `upgrade_cli`(package_id=None)
  `upgrade_all_cli`()